<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>移动到回收站</translation>
    </message>
</context>
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>移动到回收站</translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除驻留</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>驻留</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>强制退出</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>关闭所有</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除驻留</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>驻留</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>强制退出</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>关闭所有</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation>%1个文件</translation>
    </message>
</context>
</TS>
